@@ -14,30 +14,30 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package Sys::OsPackage::Driver::Debian;
-$Sys::OsPackage::Driver::Debian::VERSION = '0.3.1';
-use base "Sys::OsPackage::Driver";
+$Sys::OsPackage::Driver::Debian::VERSION = '0.4.0';
+use parent "Sys::OsPackage::Driver";
 
 # check if packager command found (deb)
 sub pkgcmd
 {
-    my ($class, $ospkg) = @_;
+    my ( $class, $ospkg ) = @_;
 
-    return (defined $ospkg->sysenv("apt") ? 1 : 0);
+    return ( defined $ospkg->sysenv("apt") ? 1 : 0 );
 }
 
 # find name of package for Perl module (deb)
 sub modpkg
 {
-    my ($class, $ospkg, $args_ref) = @_;
+    my ( $class, $ospkg, $args_ref ) = @_;
     return if not $class->pkgcmd($ospkg);
 
     # search by deb format for Perl module packages
-    my $pkgname = "lib".join("-", (map {lc $_} @{$args_ref->{mod_parts}}), "perl");
+    my $pkgname = "lib" . join( "-", ( map { lc $_ } @{ $args_ref->{mod_parts} } ), "perl" );
     $args_ref->{pkg} = $pkgname;
-    if (not $class->find($ospkg, $args_ref)) {
+    if ( not $class->find( $ospkg, $args_ref ) ) {
         return;
     }
-    $ospkg->debug() and print STDERR "debug(".__PACKAGE__."->modpkg): $pkgname\n";
+    $ospkg->debug() and print STDERR "debug(" . __PACKAGE__ . "->modpkg): $pkgname\n";
 
     # package was found - return the simpler name since pkg add won't take this full string
     return $pkgname;
@@ -47,27 +47,31 @@ sub modpkg
 # find named package in repository (deb)
 sub find
 {
-    my ($class, $ospkg, $args_ref) = @_;
+    my ( $class, $ospkg, $args_ref ) = @_;
     return if not $class->pkgcmd($ospkg);
 
     my $querycmd = $ospkg->sysenv("apt-cache");
-    my @pkglist = sort $ospkg->capture_cmd({list=>1}, $ospkg->sudo_cmd(), $querycmd, qw(search --quiet=2),
-        '^'.$args_ref->{pkg}.'$');
-    return if not scalar @pkglist; # empty list means nothing found
-    return $pkglist[-1]; # last of sorted list should be most recent version
+    my @pkglist  = sort $ospkg->capture_cmd(
+        { list => 1 },
+        $ospkg->sudo_cmd(), $querycmd,
+        qw(search --quiet=2),
+        '^' . $args_ref->{pkg} . '$'
+    );
+    return if not scalar @pkglist;    # empty list means nothing found
+    return $pkglist[-1];              # last of sorted list should be most recent version
 }
 
 # install package (deb)
 sub install
 {
-    my ($class, $ospkg, $args_ref) = @_;
+    my ( $class, $ospkg, $args_ref ) = @_;
     return if not $class->pkgcmd($ospkg);
 
     # determine packages to install
     my @packages;
-    if (defined $args_ref->{pkg}) {
-        if (ref $args_ref->{pkg} eq "ARRAY") {
-            push @packages, @{$args_ref->{pkg}};
+    if ( defined $args_ref->{pkg} ) {
+        if ( ref $args_ref->{pkg} eq "ARRAY" ) {
+            push @packages, @{ $args_ref->{pkg} };
         } else {
             push @packages, $args_ref->{pkg};
         }
@@ -75,23 +79,22 @@ sub install
 
     # install the packages
     my $pkgcmd = $ospkg->sysenv("apt");
-    return $ospkg->run_cmd($ospkg->sudo_cmd(), $pkgcmd, "install", "--yes", @packages);
+    return $ospkg->run_cmd( $ospkg->sudo_cmd(), $pkgcmd, "install", "--yes", @packages );
 }
 
 # check if an OS package is installed locally
 sub is_installed
 {
-    my ($class, $ospkg, $args_ref) = @_;
+    my ( $class, $ospkg, $args_ref ) = @_;
     return if not $class->pkgcmd($ospkg);
 
     # check if package is installed
     my $querycmd = $ospkg->sysenv("dpkg-query");
-    my @pkglist = $ospkg->capture_cmd({list=>1}, $ospkg->sudo_cmd(), $querycmd, '--show',
-        '--showformat=\${package}\n', $args_ref->{pkg});
-    return (scalar @pkglist > 0) ? 1 : 0;
+    my @pkglist  = $ospkg->capture_cmd( { list => 1 },
+        $ospkg->sudo_cmd(), $querycmd, '--show', '--showformat=\${package}\n', $args_ref->{pkg} );
+    return ( scalar @pkglist > 0 ) ? 1 : 0;
 }
 
-
 1;
 
 =pod
@@ -104,7 +107,7 @@ Sys::OsPackage::Driver::Debian - Debian/Ubuntu DEB packaging handler for Sys::Os
 
 =head1 VERSION
 
-version 0.3.1
+version 0.4.0
 
 =head1 SYNOPSIS
 
